==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/formats/microdvd/microdvdinputformat.h <==
#ifndef MICRODVDINPUTFORMAT_H
#define MICRODVDINPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <inputformat.h>
#include <qregexp.h>

namespace SubtitleComposer
{
	class MicroDVDInputFormat : public InputFormat
	{
		friend class FormatsManager;

		public:

			~MicroDVDInputFormat() {}

			virtual bool parseSubtitles( Subtitle& subtitle, bool primary, const QString& data ) const
			{
				if ( m_lineRegExp.search( data, 0 ) == -1 )
					return false; // couldn't find first line (content or FPS)

				int offset = 0;

				// if present, the FPS must by indicated by the first entry with both initial and final frames at 1
				bool ok;
				double framesPerSecond = m_lineRegExp.cap( 4 ).toDouble( &ok );
				if ( ok && m_lineRegExp.cap( 1 ) == "1" && m_lineRegExp.cap( 2 ) == "1" )
				{
					 // first line contained the frames per second
					subtitle.setFramesPerSecond( framesPerSecond );

					offset += m_lineRegExp.matchedLength();
					if ( m_lineRegExp.search( data, offset ) == -1 )
						return false; // couldn't find first line with content
				}
				else // first line doesn't contain the FPS, use the value loaded by default
					framesPerSecond = subtitle.framesPerSecond();


				unsigned readLines = 0;

				do
				{
					offset += m_lineRegExp.matchedLength();

					Time showTime( (long)((m_lineRegExp.cap( 1 ).toLong() / framesPerSecond)*1000) );
					Time hideTime( (long)((m_lineRegExp.cap( 2 ).toLong() / framesPerSecond)*1000) );

					int styleFlags = 0;
					QString styleText( m_lineRegExp.cap( 3 ) );
					if ( styleText.contains( 'b' ) )
						styleFlags |= SubtitleLine::Bold;
					if ( styleText.contains( 'i' ) )
						styleFlags |= SubtitleLine::Italic;
					if ( styleText.contains( 'u' ) )
						styleFlags |= SubtitleLine::Underline;

					QString text( m_lineRegExp.cap( 4 ) );
					text.replace( "|", "\n" );
					text.replace( m_unsupportedFormatRegExp, "" );

					setLine( subtitle, readLines, primary, text, showTime, hideTime, styleFlags );

					readLines++;
				}
				while ( m_lineRegExp.search( data, offset ) != -1 );

				return readLines > 0;
			}

		protected:

			MicroDVDInputFormat():
				InputFormat( "MicroDVD", QStringList::split( ":", "sub:txt" ) ),
				m_lineRegExp( "\\{(\\d+)\\}\\{(\\d+)\\}(\\{Y:[ubi]\\}|)([^\n]+)\n" ),
				m_unsupportedFormatRegExp( "\\{C:\\$[0-9A-Fa-f]{6,6}\\}" )
			{
			}

			mutable QRegExp m_lineRegExp;
			mutable QRegExp m_unsupportedFormatRegExp;
	};
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/formats/microdvd/microdvdinputformat.h <==
#ifndef MICRODVDINPUTFORMAT_H
#define MICRODVDINPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <inputformat.h>
#include <qregexp.h>

namespace SubtitleComposer
{
	class MicroDVDInputFormat : public InputFormat
	{
		friend class FormatManager;

		public:

			~MicroDVDInputFormat() {}

			virtual bool parseSubtitles( Subtitle& subtitle, const QString& data ) const
			{
				if ( m_lineRegExp.search( data, 0 ) == -1 )
					return false; // couldn't find first line (content or FPS)

				int offset = 0;

				// if present, the FPS must by indicated by the first entry with both initial and final frames at 1
				bool ok;
				double framesPerSecond = m_lineRegExp.cap( 4 ).toDouble( &ok );
				if ( ok && m_lineRegExp.cap( 1 ) == "1" && m_lineRegExp.cap( 2 ) == "1" )
				{
					 // first line contained the frames per second
					subtitle.setFramesPerSecond( framesPerSecond );

					offset += m_lineRegExp.matchedLength();
					if ( m_lineRegExp.search( data, offset ) == -1 )
						return false; // couldn't find first line with content
				}
				else // first line doesn't contain the FPS, use the value loaded by default
					framesPerSecond = subtitle.framesPerSecond();


				unsigned readLines = 0;

				do
				{
					offset += m_lineRegExp.matchedLength();

					Time showTime( (long)((m_lineRegExp.cap( 1 ).toLong() / framesPerSecond)*1000) );
					Time hideTime( (long)((m_lineRegExp.cap( 2 ).toLong() / framesPerSecond)*1000) );

					int styleFlags = 0;
					QString styleText( m_lineRegExp.cap( 3 ) );
					if ( styleText.contains( 'b' ) )
						styleFlags |= SString::Bold;
					if ( styleText.contains( 'i' ) )
						styleFlags |= SString::Italic;
					if ( styleText.contains( 'u' ) )
						styleFlags |= SString::Underline;

					QString text( m_lineRegExp.cap( 4 ) );
					text.replace( "|", "\n" );
					text.replace( m_unsupportedFormatRegExp, "" );

					subtitle.insertLine( new SubtitleLine( SString( text, styleFlags ), showTime, hideTime ) );

					readLines++;
				}
				while ( m_lineRegExp.search( data, offset ) != -1 );

				return readLines > 0;
			}

		protected:

			MicroDVDInputFormat():
				InputFormat( "MicroDVD", QStringList::split( ":", "sub:txt" ) ),
				m_lineRegExp( "\\{(\\d+)\\}\\{(\\d+)\\}(\\{Y:[ubi]+\\}|)([^\n]+)\n" ),
				m_unsupportedFormatRegExp( "\\{C:\\$[0-9A-Fa-f]{6,6}\\}" )
			{
			}

			mutable QRegExp m_lineRegExp;
			mutable QRegExp m_unsupportedFormatRegExp;
	};
}

#endif
